@@ -8,5 +8,5 @@ from .worker import EmitWorker
 from .worker_group import EmitWorkerGroup
 from .worker_master import EmitWorkerMaster
 from .builder import EmitWorkerBuilder
-from .factory import EmitWorkerGroupFactory, EmitWorkerMasterFactory
+from .factory import EmitWorkerGroupFactory, EmitWorkerMasterFactory, is_worker, is_group, run
 from .decorate import emit_decorate
